@@ -72,11 +72,13 @@ r_process_options_default <- function() {
     error = getOption("callr.error", "error"),
     cmdargs = c("--slave", "--no-save", "--no-restore"),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = character(),
     supervise = FALSE,
-    load_hook = NULL,
-    extra = list()
+    load_hook = default_load_hook(),
+    extra = list(),
+    package = FALSE,
+    arch = "same"
   )
 }
 
@@ -90,11 +92,12 @@ rcmd_process_options_default <- function() {
     poll_connection = TRUE,
     repos = default_repos(),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = rcmd_safe_env(),
     wd = ".",
     supervise = FALSE,
-    extra = list()
+    extra = list(),
+    arch = "same"
   )
 }
 
@@ -108,11 +111,12 @@ rscript_process_options_default <- function() {
     poll_connection = TRUE,
     repos = default_repos(),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = rcmd_safe_env(),
     wd = ".",
     color = FALSE,
-    extra = list()
+    extra = list(),
+    arch = "same"
   )
 }
 
@@ -125,7 +129,7 @@ update_options <- function(old_opts, ...) {
 
 check_for_option_names <- function(old, new) {
   if (length(miss <- setdiff(names(new), names(old)))) {
-    stop("Unknown option", if (length(miss) > 1) "s", ":",
-         enumerate(sQuote(miss)))
+    throw(new_error("Unknown option", if (length(miss) > 1) "s", ":",
+                    enumerate(sQuote(miss))))
   }
 }
